# Contributing to llm-code-format

Thank you for your interest in contributing to llm-code-format! We welcome contributions from the community to help make this project better.

## Getting Started

1. **Create an Issue First**

   - Before submitting a Pull Request, please create an issue to discuss the changes you'd like to make
   - This helps avoid duplicate work and ensures your contribution aligns with the project's goals
   - Link your PR to the issue when you create it

2. **Fork and Clone**

   - Fork the repository on GitHub
   - Clone your fork locally

   ```bash
   git clone https://github.com/YOUR-USERNAME/llm-code-format.git
   cd llm-code-format
   ```

3. **Install Dependencies**

   ```bash
   npm install
   ```

4. **Create a Branch**
   ```bash
   git checkout -b feature/your-feature-name
   ```

## Development Guidelines

1. **Code Style**

   - Use TypeScript
   - Follow existing code formatting
   - Add appropriate comments for complex logic
   - Keep functions focused and modular

2. **Testing**

   - Add tests for new features
   - Ensure all tests pass before submitting PR
   - Run tests with `npm test`

3. **Documentation**
   - Update README.md if adding new features
   - Add JSDoc comments for new functions
   - Include examples in documentation

## Pull Request Process

1. **Before Submitting**

   - Ensure code builds without errors
   - Run all tests
   - Update documentation as needed
   - Add your changes to CHANGELOG.md

2. **PR Guidelines**

   - Link to the related issue
   - Provide a clear description of changes
   - Include any necessary documentation updates
   - List any breaking changes

3. **Review Process**
   - Maintainers will review your PR
   - Address any requested changes
   - Once approved, maintainers will merge your PR

## License

By contributing to llm-code-format, you agree that your contributions will be licensed under the MIT License.
